---
name: Bug report
about: Create a bug report
title: ''
labels: ''
assignees: ''

---

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Steps to reproduce the behavior:
1. Go to '...'
2. Click on '....'
3. Scroll down to '....'
4. See error

**Expected behavior**
A clear and concise description of what you expected to happen.

**Screenshots**
If applicable, add screenshots to help explain your problem.

**What you have tried to fix the error**
If applicable, a list of everything you have tried to fix the problem.

**Information (please complete the following information):**
 - OS: [e.g. Linux]
 - Distro: [e.g Fedora] (only if applicable)
 - OS Version: [e.g. 40]
 - PySoundSphere Version: [e.g. 1.0]
 - Sound Backend: : [e.g. PyAudio]
 - ...

**Additional context**
Add any other context about the problem here.

**Traceback**
If applicable, include a Traceback or some other kind of crash report.

